# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../Emulator/RNBIP Qt Source/GUI_TEST/mainwidow.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWidow(object):
    def setupUi(self, MainWidow):
        MainWidow.setObjectName("MainWidow")
        MainWidow.resize(1366, 721)
        label_font = QtGui.QFont()
        label_font.setPointSize(10)
        label_font.setBold(False)
        label_font.setWeight(75)
        self.centralWidget = QtWidgets.QWidget(MainWidow)
        self.centralWidget.setMinimumSize(QtCore.QSize(1110, 0))
        self.centralWidget.setObjectName("centralWidget")
        self.imageLabel_Source = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_Source.setGeometry(QtCore.QRect(-190, 240, 701, 671))
        self.imageLabel_Source.setText("")
        self.imageLabel_Source.setObjectName("imageLabel_Source")
        self.layoutWidget = QtWidgets.QWidget(self.centralWidget)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 160, 151, 91))
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName("verticalLayout")
        self.nextStage = QtWidgets.QPushButton(self.centralWidget)
        self.nextStage.setFont(label_font)
        self.nextStage.setGeometry(QtCore.QRect(650, 540, 180, 51))
        self.nextStage.setAutoFillBackground(False)
        self.nextStage.setObjectName("nextStage")
        self.imageLabel_2 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_2.setGeometry(QtCore.QRect(-120, 280, 701, 671))
        self.imageLabel_2.setText("")
        self.imageLabel_2.setObjectName("imageLabel_2")
        self.imageLabel_3 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_3.setGeometry(QtCore.QRect(-160, 270, 701, 671))
        self.imageLabel_3.setText("")
        self.imageLabel_3.setObjectName("imageLabel_3")
        self.imageLabel_4 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_4.setGeometry(QtCore.QRect(-270, 290, 701, 671))
        self.imageLabel_4.setText("")
        self.imageLabel_4.setObjectName("imageLabel_4")
        self.imageLabel_5 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_5.setGeometry(QtCore.QRect(-210, 280, 701, 671))
        self.imageLabel_5.setText("")
        self.imageLabel_5.setObjectName("imageLabel_5")
        self.imageLabel_6 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_6.setGeometry(QtCore.QRect(-190, 280, 701, 671))
        self.imageLabel_6.setText("")
        self.imageLabel_6.setObjectName("imageLabel_6")
        self.imageLabel_7 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_7.setGeometry(QtCore.QRect(-200, 230, 701, 671))
        self.imageLabel_7.setText("")
        self.imageLabel_7.setObjectName("imageLabel_7")
        self.imageLabel_8 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_8.setGeometry(QtCore.QRect(-180, 290, 701, 671))
        self.imageLabel_8.setText("")
        self.imageLabel_8.setObjectName("imageLabel_8")
        self.imageLabel_9 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_9.setGeometry(QtCore.QRect(-250, 220, 701, 671))
        self.imageLabel_9.setText("")
        self.imageLabel_9.setObjectName("imageLabel_9")
        self.imageLabel_10 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_10.setGeometry(QtCore.QRect(-180, 280, 701, 671))
        self.imageLabel_10.setText("")
        self.imageLabel_10.setObjectName("imageLabel_10")
        self.imageLabel_11 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_11.setGeometry(QtCore.QRect(-190, 280, 701, 671))
        self.imageLabel_11.setText("")
        self.imageLabel_11.setObjectName("imageLabel_11")
        self.imageLabel_12 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_12.setGeometry(QtCore.QRect(-200, 290, 701, 671))
        self.imageLabel_12.setText("")
        self.imageLabel_12.setObjectName("imageLabel_12")
        self.imageLabel_13 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_13.setGeometry(QtCore.QRect(-190, 250, 701, 671))
        self.imageLabel_13.setText("")
        self.imageLabel_13.setObjectName("imageLabel_13")
        self.imageLabel_14 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_14.setGeometry(QtCore.QRect(-230, 250, 701, 671))
        self.imageLabel_14.setText("")
        self.imageLabel_14.setObjectName("imageLabel_14")
        self.imageLabel_15 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_15.setGeometry(QtCore.QRect(-320, 160, 701, 671))
        self.imageLabel_15.setText("")
        self.imageLabel_15.setObjectName("imageLabel_15")
        self.imageLabel_16 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_16.setGeometry(QtCore.QRect(880, 390, 701, 671))
        self.imageLabel_16.setText("")
        self.imageLabel_16.setObjectName("imageLabel_16")
        self.imageLabel_17 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_17.setGeometry(QtCore.QRect(810, 400, 701, 671))
        self.imageLabel_17.setText("")
        self.imageLabel_17.setObjectName("imageLabel_17")
        self.imageLabel_18 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_18.setGeometry(QtCore.QRect(960, 400, 701, 671))
        self.imageLabel_18.setText("")
        self.imageLabel_18.setObjectName("imageLabel_18")
        self.imageLabel_19 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_19.setGeometry(QtCore.QRect(820, 400, 701, 671))
        self.imageLabel_19.setText("")
        self.imageLabel_19.setObjectName("imageLabel_19")
        self.imageLabel_20 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_20.setGeometry(QtCore.QRect(830, 400, 701, 671))
        self.imageLabel_20.setText("")
        self.imageLabel_20.setObjectName("imageLabel_20")
        self.imageLabel_21 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_21.setGeometry(QtCore.QRect(-140, 410, 701, 671))
        self.imageLabel_21.setText("")
        self.imageLabel_21.setObjectName("imageLabel_21")
        self.imageLabel_22 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_22.setGeometry(QtCore.QRect(-200, 30, 701, 671))
        self.imageLabel_22.setText("")
        self.imageLabel_22.setObjectName("imageLabel_22")
        self.imageLabel = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel.setGeometry(QtCore.QRect(40, 40, 5, 13))
        self.imageLabel.setText("")
        self.imageLabel.setObjectName("imageLabel")
        self.plainTextEdit = QtWidgets.QPlainTextEdit(self.centralWidget)
        self.plainTextEdit.setGeometry(QtCore.QRect(920, 60, 421, 221))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        self.plainTextEdit.setFont(font)
        self.plainTextEdit.setAutoFillBackground(False)
        self.plainTextEdit.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.plainTextEdit.setTabChangesFocus(False)
        self.plainTextEdit.setBackgroundVisible(False)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.pushButton = QtWidgets.QPushButton(self.centralWidget)
        self.pushButton.setGeometry(QtCore.QRect(1040, 290, 81, 23))
        self.pushButton.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.pushButton.setAutoDefault(False)
        self.pushButton.setDefault(False)
        self.pushButton.setFlat(False)
        self.pushButton.setObjectName("pushButton")
        self.logBox = QtWidgets.QTextBrowser(self.centralWidget)
        self.logBox.setGeometry(QtCore.QRect(920, 330, 421, 192))
        self.logBox.viewport().setProperty("cursor", QtGui.QCursor(QtCore.Qt.IBeamCursor))
        self.logBox.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.logBox.setFrameShadow(QtWidgets.QFrame.Plain)
        self.logBox.setObjectName("logBox")
        self.scrollArea = QtWidgets.QScrollArea(self.centralWidget)
        self.scrollArea.setGeometry(QtCore.QRect(919, 330, 421, 91))
        self.scrollArea.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 421, 91))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.gridLayoutWidget = QtWidgets.QWidget(self.centralWidget)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(630, 260, 201, 268))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setContentsMargins(11, 11, 11, 11)
        self.gridLayout.setSpacing(6)
        self.gridLayout.setObjectName("gridLayout")
        self.R2_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R2_value.setFont(font)
        self.R2_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R2_value.setObjectName("R2_value")
        self.gridLayout.addWidget(self.R2_value, 4, 2, 1, 1)
        self.R2 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R2.setFont(font)
        self.R2.setAlignment(QtCore.Qt.AlignCenter)
        self.R2.setObjectName("R2")
        self.gridLayout.addWidget(self.R2, 4, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.gridLayoutWidget)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout.addWidget(self.line, 2, 1, 8, 1)
        self.label_8 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        self.label_8.setFont(font)
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setObjectName("label_8")
        self.label_8.setFont(label_font)
        self.gridLayout.addWidget(self.label_8, 0, 0, 1, 3)
        self.R3_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R3_value.setFont(font)
        self.R3_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R3_value.setObjectName("R3_value")
        self.gridLayout.addWidget(self.R3_value, 5, 2, 1, 1)
        self.R0_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R0_value.setFont(font)
        self.R0_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R0_value.setObjectName("R0_value")
        self.gridLayout.addWidget(self.R0_value, 2, 2, 1, 1)
        self.R1_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R1_value.setFont(font)
        self.R1_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R1_value.setObjectName("R1_value")
        self.gridLayout.addWidget(self.R1_value, 3, 2, 1, 1)
        self.R4_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R4_value.setFont(font)
        self.R4_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R4_value.setObjectName("R4_value")
        self.gridLayout.addWidget(self.R4_value, 6, 2, 1, 1)
        self.R4 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R4.setFont(font)
        self.R4.setAlignment(QtCore.Qt.AlignCenter)
        self.R4.setObjectName("R4")
        self.gridLayout.addWidget(self.R4, 6, 0, 1, 1)
        self.R0 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R0.setFont(font)
        self.R0.setAlignment(QtCore.Qt.AlignCenter)
        self.R0.setObjectName("R0")
        self.gridLayout.addWidget(self.R0, 2, 0, 1, 1)
        self.R1 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R1.setFont(font)
        self.R1.setAlignment(QtCore.Qt.AlignCenter)
        self.R1.setObjectName("R1")
        self.gridLayout.addWidget(self.R1, 3, 0, 1, 1)
        self.R7_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R7_value.setFont(font)
        self.R7_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R7_value.setObjectName("R7_value")
        self.gridLayout.addWidget(self.R7_value, 9, 2, 1, 1)
        self.R6 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R6.setFont(font)
        self.R6.setAlignment(QtCore.Qt.AlignCenter)
        self.R6.setObjectName("R6")
        self.gridLayout.addWidget(self.R6, 8, 0, 1, 1)
        self.R6_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R6_value.setFont(font)
        self.R6_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R6_value.setObjectName("R6_value")
        self.gridLayout.addWidget(self.R6_value, 8, 2, 1, 1)
        self.R7 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R7.setFont(font)
        self.R7.setAlignment(QtCore.Qt.AlignCenter)
        self.R7.setObjectName("R7")
        self.gridLayout.addWidget(self.R7, 9, 0, 1, 1)
        self.R5 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R5.setFont(font)
        self.R5.setAlignment(QtCore.Qt.AlignCenter)
        self.R5.setObjectName("R5")
        self.gridLayout.addWidget(self.R5, 7, 0, 1, 1)
        self.R5_value = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.R5_value.setFont(font)
        self.R5_value.setAlignment(QtCore.Qt.AlignCenter)
        self.R5_value.setObjectName("R5_value")
        self.gridLayout.addWidget(self.R5_value, 7, 2, 1, 1)
        self.R3 = QtWidgets.QLabel(self.gridLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.R3.setFont(font)
        self.R3.setAlignment(QtCore.Qt.AlignCenter)
        self.R3.setObjectName("R3")
        self.gridLayout.addWidget(self.R3, 5, 0, 1, 1)
        self.line_6 = QtWidgets.QFrame(self.gridLayoutWidget)
        self.line_6.setLineWidth(2)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.gridLayout.addWidget(self.line_6, 1, 0, 1, 3)
        self.formLayoutWidget = QtWidgets.QWidget(self.centralWidget)
        self.formLayoutWidget.setGeometry(QtCore.QRect(0, 10, 1371, 120))
        self.formLayoutWidget.setObjectName("formLayoutWidget")
        self.formLayout = QtWidgets.QFormLayout(self.formLayoutWidget)
        self.formLayout.setContentsMargins(11, 11, 11, 11)
        self.formLayout.setSpacing(6)
        self.formLayout.setObjectName("formLayout")
        self.Instruction_value = QtWidgets.QLabel(self.formLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(20)
        self.Instruction_value.setFont(font)
        self.Instruction_value.setAlignment(QtCore.Qt.AlignCenter)
        self.Instruction_value.setObjectName("Instruction_value")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.Instruction_value)
        self.IR_value = QtWidgets.QLabel(self.formLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(14)
        self.IR_value.setFont(font)
        self.IR_value.setAlignment(QtCore.Qt.AlignCenter)
        self.IR_value.setObjectName("IR_value")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.IR_value)
        self.IR_value.raise_()
        self.Instruction_value.raise_()
        self.imageLabel_23 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_23.setGeometry(QtCore.QRect(270, 640, 701, 671))
        self.imageLabel_23.setText("")
        self.imageLabel_23.setObjectName("imageLabel_23")
        self.imageLabel_24 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_24.setGeometry(QtCore.QRect(-330, 300, 701, 671))
        self.imageLabel_24.setObjectName("imageLabel_24")
        self.pushButton_2 = QtWidgets.QPushButton(self.centralWidget)
        self.pushButton_2.setGeometry(QtCore.QRect(1130, 290, 81, 23))
        self.pushButton_2.setObjectName("pushButton_2")
        self.tableWidget = QtWidgets.QTableWidget(self.centralWidget)
        self.tableWidget.setGeometry(QtCore.QRect(1140, 470, 201, 192))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget.sizePolicy().hasHeightForWidth())
        self.tableWidget.setSizePolicy(sizePolicy)
        self.tableWidget.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.tableWidget.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.tableWidget.setAutoScroll(True)
        self.tableWidget.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidget.setDragEnabled(True)
        self.tableWidget.setDragDropMode(QtWidgets.QAbstractItemView.NoDragDrop)
        self.tableWidget.setDefaultDropAction(QtCore.Qt.IgnoreAction)
        self.tableWidget.setAlternatingRowColors(True)
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(0)
        self.tableWidget.setRowCount(0)
        self.imageLabel_25 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_25.setGeometry(QtCore.QRect(1180, 260, 701, 671))
        self.imageLabel_25.setText("")
        self.imageLabel_25.setObjectName("imageLabel_25")
        self.imageLabel_26 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_26.setGeometry(QtCore.QRect(-210, 280, 701, 671))
        self.imageLabel_26.setText("")
        self.imageLabel_26.setObjectName("imageLabel_26")
        self.imageLabel_27 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_27.setGeometry(QtCore.QRect(1170, 280, 701, 671))
        self.imageLabel_27.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_27.setText("")
        self.imageLabel_27.setObjectName("imageLabel_27")
        self.gridLayoutWidget_3 = QtWidgets.QWidget(self.centralWidget)
        self.gridLayoutWidget_3.setGeometry(QtCore.QRect(610, 150, 241, 80))
        self.gridLayoutWidget_3.setObjectName("gridLayoutWidget_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.gridLayoutWidget_3)
        self.gridLayout_3.setContentsMargins(11, 11, 11, 11)
        self.gridLayout_3.setSpacing(6)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.PC_value = QtWidgets.QLabel(self.gridLayoutWidget_3)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.PC_value.setFont(font)
        self.PC_value.setAlignment(QtCore.Qt.AlignCenter)
        self.PC_value.setObjectName("PC_value")
        self.gridLayout_3.addWidget(self.PC_value, 1, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.gridLayoutWidget_3)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.label.setFont(font)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 1, 1, 1)
        self.SP_value = QtWidgets.QLabel(self.gridLayoutWidget_3)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.SP_value.setFont(font)
        self.SP_value.setAlignment(QtCore.Qt.AlignCenter)
        self.SP_value.setObjectName("SP_value")
        self.gridLayout_3.addWidget(self.SP_value, 1, 1, 1, 1)
        self.PCLabel = QtWidgets.QLabel(self.gridLayoutWidget_3)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.PCLabel.setFont(font)
        self.PCLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.PCLabel.setObjectName("PCLabel")
        self.gridLayout_3.addWidget(self.PCLabel, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.gridLayoutWidget_3)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.label_2.setFont(font)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 0, 2, 1, 1)
        self.OR_value = QtWidgets.QLabel(self.gridLayoutWidget_3)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.OR_value.setFont(font)
        self.OR_value.setAlignment(QtCore.Qt.AlignCenter)
        self.OR_value.setObjectName("OR_value")
        self.gridLayout_3.addWidget(self.OR_value, 1, 2, 1, 1)
        self.reset = QtWidgets.QPushButton(self.centralWidget)
        self.reset.setGeometry(QtCore.QRect(700, 610, 75, 23))
        self.reset.setObjectName("reset")
        self.imageLabel_28 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_28.setGeometry(QtCore.QRect(1210, 50, 701, 671))
        self.imageLabel_28.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_28.setText("")
        self.imageLabel_28.setObjectName("imageLabel_28")
        self.imageLabel_29 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_29.setGeometry(QtCore.QRect(1210, 50, 701, 671))
        self.imageLabel_29.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_29.setText("")
        self.imageLabel_29.setObjectName("imageLabel_29")
        self.imageLabel_30 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_30.setGeometry(QtCore.QRect(1210, 50, 701, 671))
        self.imageLabel_30.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_30.setText("")
        self.imageLabel_30.setObjectName("imageLabel_30")
        self.imageLabel_31 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_31.setGeometry(QtCore.QRect(1210, 50, 701, 671))
        self.imageLabel_31.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_31.setText("")
        self.imageLabel_31.setObjectName("imageLabel_31")
        self.imageLabel_32 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_32.setGeometry(QtCore.QRect(1210, 50, 701, 671))
        self.imageLabel_32.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_32.setText("")
        self.imageLabel_32.setObjectName("imageLabel_32")
        self.imageLabel_33 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_33.setGeometry(QtCore.QRect(1210, 50, 701, 671))
        self.imageLabel_33.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_33.setText("")
        self.imageLabel_33.setObjectName("imageLabel_33")
        self.imageLabel_34 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_34.setGeometry(QtCore.QRect(-150, 50, 701, 671))
        self.imageLabel_34.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_34.setText("")
        self.imageLabel_34.setObjectName("imageLabel_34")
        self.imageLabel_35 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_35.setGeometry(QtCore.QRect(-330, 50, 701, 671))
        self.imageLabel_35.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_35.setText("")
        self.imageLabel_35.setObjectName("imageLabel_35")
        self.imageLabel_36 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_36.setGeometry(QtCore.QRect(1240, 10, 701, 671))
        self.imageLabel_36.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_36.setText("")
        self.imageLabel_36.setObjectName("imageLabel_36")
        self.tableWidget_2 = QtWidgets.QTableWidget(self.centralWidget)
        self.tableWidget_2.setGeometry(QtCore.QRect(920, 470, 101, 192))
        self.tableWidget_2.setLineWidth(1)
        self.tableWidget_2.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.tableWidget_2.setAutoScroll(True)
        self.tableWidget_2.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidget_2.setDragEnabled(True)
        self.tableWidget_2.setDragDropMode(QtWidgets.QAbstractItemView.NoDragDrop)
        self.tableWidget_2.setDefaultDropAction(QtCore.Qt.IgnoreAction)
        self.tableWidget_2.setAlternatingRowColors(True)
        self.tableWidget_2.setObjectName("tableWidget_2")
        self.tableWidget_2.setColumnCount(0)
        self.tableWidget_2.setRowCount(0)
        self.imageLabel_37 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_37.setGeometry(QtCore.QRect(1000, 80, 701, 671))
        self.imageLabel_37.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_37.setText("")
        self.imageLabel_37.setObjectName("imageLabel_37")
        self.run10ClockCycle = QtWidgets.QPushButton(self.centralWidget)
        self.run10ClockCycle.setGeometry(QtCore.QRect(680, 640, 111, 51))
        self.run10ClockCycle.setObjectName("run10ClockCycle")
        self.imageLabel_38 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_38.setGeometry(QtCore.QRect(-160, 10, 701, 671))
        self.imageLabel_38.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_38.setText("")
        self.imageLabel_38.setObjectName("imageLabel_38")
        self.imageLabel_39 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_39.setGeometry(QtCore.QRect(-150, 10, 701, 671))
        self.imageLabel_39.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_39.setText("")
        self.imageLabel_39.setObjectName("imageLabel_39")
        self.imageLabel_40 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_40.setGeometry(QtCore.QRect(890, 220, 701, 671))
        self.imageLabel_40.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_40.setText("")
        self.imageLabel_40.setObjectName("imageLabel_40")
        self.imageLabel_41 = QtWidgets.QLabel(self.centralWidget)
        self.imageLabel_41.setGeometry(QtCore.QRect(1310, 540, 701, 671))
        self.imageLabel_41.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imageLabel_41.setText("")
        self.imageLabel_41.setObjectName("imageLabel_41")
        self.label_3 = QtWidgets.QLabel(self.centralWidget)
        self.label_3.setGeometry(QtCore.QRect(920, 40, 80, 13))
        self.label_3.setObjectName("label_3")
        self.label_3.setFont(label_font)
        self.label_4 = QtWidgets.QLabel(self.centralWidget)
        self.label_4.setGeometry(QtCore.QRect(920, 310, 47, 13))
        self.label_4.setObjectName("label_4")
        self.label_4.setFont(label_font)
        self.state_3 = QtWidgets.QLabel(self.centralWidget)
        self.state_3.setGeometry(QtCore.QRect(40, 130, 1363, 23))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.state_3.setFont(font)
        self.state_3.setAlignment(QtCore.Qt.AlignCenter)
        self.state_3.setObjectName("state_3")
        self.state = QtWidgets.QLabel(self.centralWidget)
        self.state.setGeometry(QtCore.QRect(70, 130, 1363, 23))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.state.setFont(font)
        self.state.setAlignment(QtCore.Qt.AlignCenter)
        self.state.setObjectName("state")
        self.imageLabel_37.raise_()
        self.imageLabel_Source.raise_()
        self.layoutWidget.raise_()
        self.imageLabel_2.raise_()
        self.imageLabel_3.raise_()
        self.imageLabel_4.raise_()
        self.imageLabel_5.raise_()
        self.imageLabel_6.raise_()
        self.imageLabel_7.raise_()
        self.imageLabel_8.raise_()
        self.imageLabel_9.raise_()
        self.imageLabel_10.raise_()
        self.imageLabel_11.raise_()
        self.imageLabel_12.raise_()
        self.imageLabel_13.raise_()
        self.imageLabel_14.raise_()
        self.imageLabel_15.raise_()
        self.imageLabel_16.raise_()
        self.imageLabel_17.raise_()
        self.imageLabel_18.raise_()
        self.imageLabel_19.raise_()
        self.imageLabel_20.raise_()
        self.imageLabel_21.raise_()
        self.imageLabel_22.raise_()
        self.imageLabel.raise_()
        self.nextStage.raise_()
        self.pushButton.raise_()
        self.logBox.raise_()
        self.scrollArea.raise_()
        self.gridLayoutWidget.raise_()
        self.formLayoutWidget.raise_()
        self.imageLabel_23.raise_()
        self.imageLabel_24.raise_()
        self.pushButton_2.raise_()
        self.imageLabel_25.raise_()
        self.imageLabel_27.raise_()
        self.imageLabel_26.raise_()
        self.gridLayoutWidget_3.raise_()
        self.reset.raise_()
        self.imageLabel_28.raise_()
        self.imageLabel_29.raise_()
        self.imageLabel_31.raise_()
        self.imageLabel_32.raise_()
        self.imageLabel_33.raise_()
        self.imageLabel_34.raise_()
        self.imageLabel_35.raise_()
        self.imageLabel_36.raise_()
        self.tableWidget_2.raise_()
        self.plainTextEdit.raise_()
        self.tableWidget.raise_()
        self.run10ClockCycle.raise_()
        self.imageLabel_38.raise_()
        self.imageLabel_39.raise_()
        self.imageLabel_40.raise_()
        self.imageLabel_41.raise_()
        self.label_3.raise_()
        self.label_4.raise_()
        self.imageLabel_30.raise_()
        self.state_3.raise_()
        self.state.raise_()
        MainWidow.setCentralWidget(self.centralWidget)
        self.menuBar = QtWidgets.QMenuBar(MainWidow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1366, 21))
        self.menuBar.setObjectName("menuBar")
        MainWidow.setMenuBar(self.menuBar)
        self.statusBar = QtWidgets.QStatusBar(MainWidow)
        self.statusBar.setObjectName("statusBar")
        MainWidow.setStatusBar(self.statusBar)
        self.actionReset = QtWidgets.QAction(MainWidow)
        self.actionReset.setObjectName("actionReset")
        self.actionNext_Cycle = QtWidgets.QAction(MainWidow)
        self.actionNext_Cycle.setObjectName("actionNext_Cycle")
        self.actionExit = QtWidgets.QAction(MainWidow)
        self.actionExit.setObjectName("actionExit")
        self.ResetAction = QtWidgets.QAction(MainWidow)
        self.ResetAction.setObjectName("ResetAction")

        self.retranslateUi(MainWidow)
        # QtCore.QMetaObject.connectSlotsByName(MainWidow)

    def retranslateUi(self, MainWidow):
        _translate = QtCore.QCoreApplication.translate
        MainWidow.setWindowTitle(_translate("MainWidow", "MainWidow"))
        self.nextStage.setText(_translate("MainWidow", "Next Clock Cycle"))
        self.pushButton.setText(_translate("MainWidow", "Compile"))
        self.R2_value.setText(_translate("MainWidow", "XX"))
        self.R2.setText(_translate("MainWidow", "R2"))
        self.label_8.setText(_translate("MainWidow", "Register Array"))
        self.R3_value.setText(_translate("MainWidow", "XX"))
        self.R0_value.setText(_translate("MainWidow", "XX"))
        self.R1_value.setText(_translate("MainWidow", "XX"))
        self.R4_value.setText(_translate("MainWidow", "XX"))
        self.R4.setText(_translate("MainWidow", "R4"))
        self.R0.setText(_translate("MainWidow", "R0"))
        self.R1.setText(_translate("MainWidow", "R1"))
        self.R7_value.setText(_translate("MainWidow", "XX"))
        self.R6.setText(_translate("MainWidow", "R6"))
        self.R6_value.setText(_translate("MainWidow", "XX"))
        self.R7.setText(_translate("MainWidow", "R7"))
        self.R5.setText(_translate("MainWidow", "R5"))
        self.R5_value.setText(_translate("MainWidow", "XX"))
        self.R3.setText(_translate("MainWidow", "R3"))
        self.Instruction_value.setText(_translate("MainWidow", "TextLabel"))
        self.IR_value.setText(_translate("MainWidow", "TextLabel"))
        self.imageLabel_24.setText(_translate("MainWidow", "Zero"))
        self.pushButton_2.setText(_translate("MainWidow", "View Log"))
        self.PC_value.setText(_translate("MainWidow", "0"))
        self.label.setText(_translate("MainWidow", "SP"))
        self.SP_value.setText(_translate("MainWidow", "FF"))
        self.PCLabel.setText(_translate("MainWidow", "PC"))
        self.label_2.setText(_translate("MainWidow", "OR"))
        self.OR_value.setText(_translate("MainWidow", "XX"))
        self.reset.setText(_translate("MainWidow", "Reset"))
        self.run10ClockCycle.setText(_translate("MainWidow", "Run 10 Cycles"))
        self.label_3.setText(_translate("MainWidow", "EDITOR"))
        self.label_4.setText(_translate("MainWidow", "LOG"))
        self.state_3.setText(_translate("MainWidow", "State :    "))
        self.state.setText(_translate("MainWidow", "XX"))
        self.actionReset.setText(_translate("MainWidow", "Reset"))
        self.actionNext_Cycle.setText(_translate("MainWidow", "Next Cycle"))
        self.actionExit.setText(_translate("MainWidow", "Exit"))
        self.ResetAction.setText(_translate("MainWidow", "Reset"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWidow = QtWidgets.QMainWindow()
    ui = Ui_MainWidow()
    ui.setupUi(MainWidow)
    MainWidow.show()
    sys.exit(app.exec_())
